"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryActivityCounters = exports.getActivityCounters = exports.incrementActivityCounters = exports.setActivityCounters = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressMembersActivitycountersActivityCountersUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/activity-counters-api',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        _: [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/members/v1/activity-counters',
                destPath: '/v1/activity-counters',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_activity-counters_activity-counters';
/**
 * Sets activity counters for a requested site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
function setActivityCounters(payload) {
    function __setActivityCounters({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.activity_counter',
            method: 'PUT',
            methodFqn: 'com.wixpress.members.activitycounters.ActivityCounters.SetActivityCounters',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersActivitycountersActivityCountersUrl({
                protoPath: '/v1/activity-counters/{memberId}',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __setActivityCounters;
}
exports.setActivityCounters = setActivityCounters;
/**
 * Increments a specific activity counters for a specified site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
function incrementActivityCounters(payload) {
    function __incrementActivityCounters({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.activity_counter',
            method: 'PUT',
            methodFqn: 'com.wixpress.members.activitycounters.ActivityCounters.IncrementActivityCounters',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersActivitycountersActivityCountersUrl({
                protoPath: '/v1/activity-counters/{memberId}/increment',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __incrementActivityCounters;
}
exports.incrementActivityCounters = incrementActivityCounters;
/**
 * Retrieves activity counters for the specified site member, including all public counters and any private counters owned by the authenticated caller.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
function getActivityCounters(payload) {
    function __getActivityCounters({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.activity_counter',
            method: 'GET',
            methodFqn: 'com.wixpress.members.activitycounters.ActivityCounters.GetActivityCounters',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersActivitycountersActivityCountersUrl({
                protoPath: '/v1/activity-counters/{memberId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __getActivityCounters;
}
exports.getActivityCounters = getActivityCounters;
/**
 * Returns up to 100 public activity counters for the provided filter and paging.
 *
 * Only counters that are marked as public are returned.
 *
 * Supported fields for filtering:
 * - `memberId`
 *
 * Supported operations:
 *
 * Comparison:
 * - $eq
 * - $ne
 * - $in
 *
 * Logical:
 * - $and
 * - $not
 * - $or
 */
function queryActivityCounters(payload) {
    function __queryActivityCounters({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.activity_counter',
            method: 'POST',
            methodFqn: 'com.wixpress.members.activitycounters.ActivityCounters.QueryActivityCounters',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersActivitycountersActivityCountersUrl({
                protoPath: '/v1/activity-counters/query',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __queryActivityCounters;
}
exports.queryActivityCounters = queryActivityCounters;
//# sourceMappingURL=members-v1-activity-counter-activity-counters.http.js.map