"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryActivityCounters = exports.getActivityCounters = exports.incrementActivityCounters = exports.setActivityCounters = exports.WebhookIdentityType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixMembersV1ActivityCounter = __importStar(require("./members-v1-activity-counter-activity-counters.http.js"));
// @ts-ignore
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Sets activity counters for a requested site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counter will be set.
 * @param counter - Counter data for this site member.
 * @public
 * @requiredField counter
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_WRITE
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.SetActivityCounters
 */
async function setActivityCounters(memberId, counter) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        memberId: memberId,
        counter: counter,
    });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.setActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', counter: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'counter']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.setActivityCounters = setActivityCounters;
/**
 * Increments a specific activity counters for a specified site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counter will be incremented.
 * @param counter - Counter data for this site member.
 * @public
 * @requiredField counter
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_WRITE
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.IncrementActivityCounters
 */
async function incrementActivityCounters(memberId, counter) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        memberId: memberId,
        counter: counter,
    });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.incrementActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', counter: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'counter']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.incrementActivityCounters = incrementActivityCounters;
/**
 * Retrieves activity counters for the specified site member, including all public counters and any private counters owned by the authenticated caller.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counters will be returned.
 * @public
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_READ
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @permissionScope Read Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.GetActivityCounters
 */
async function getActivityCounters(memberId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ memberId: memberId });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.getActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['memberId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getActivityCounters = getActivityCounters;
/**
 * Returns up to 100 public activity counters for the provided filter and paging.
 *
 * Only counters that are marked as public are returned.
 *
 * Supported fields for filtering:
 * - `memberId`
 *
 * Supported operations:
 *
 * Comparison:
 * - $eq
 * - $ne
 * - $in
 *
 * Logical:
 * - $and
 * - $not
 * - $or
 * @public
 * @param options - Information about the activity counters to retrieve.
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @permissionScope Read Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-ACTIVITY-COUNTERS
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_READ
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.QueryActivityCounters
 */
function queryActivityCounters() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixMembersV1ActivityCounter.queryActivityCounters(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(data, []));
            return {
                items: transformedData?.activityCounters,
                pagingMetadata: transformedData?.metadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
exports.queryActivityCounters = queryActivityCounters;
//# sourceMappingURL=members-v1-activity-counter-activity-counters.universal.js.map