import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { ActivityCounterUpdatedEnvelope, ActivityCountersQueryBuilder, Counter, GetActivityCountersResponse, IncrementActivityCountersResponse, SetActivityCountersResponse } from './members-v1-activity-counter-activity-counters.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function setActivityCounters(httpClient: HttpClient): SetActivityCountersSignature;
interface SetActivityCountersSignature {
    /**
     * Sets activity counters for a requested site member.
     *
     * If the counter does not already exist, it will be created.
     *
     * Counters are identified with a custom key, which must be unique.
     *
     * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
     * @param - Member ID whose counter will be set.
     * @param - Counter data for this site member.
     */
    (memberId: string, counter: Counter): Promise<SetActivityCountersResponse>;
}
export declare function incrementActivityCounters(httpClient: HttpClient): IncrementActivityCountersSignature;
interface IncrementActivityCountersSignature {
    /**
     * Increments a specific activity counters for a specified site member.
     *
     * If the counter does not already exist, it will be created.
     *
     * Counters are identified with a custom key, which must be unique.
     *
     * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
     * @param - Member ID whose counter will be incremented.
     * @param - Counter data for this site member.
     */
    (memberId: string, counter: Counter): Promise<IncrementActivityCountersResponse>;
}
export declare function getActivityCounters(httpClient: HttpClient): GetActivityCountersSignature;
interface GetActivityCountersSignature {
    /**
     * Retrieves activity counters for the specified site member, including all public counters and any private counters owned by the authenticated caller.
     *
     * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
     * @param - Member ID whose counters will be returned.
     */
    (memberId: string): Promise<GetActivityCountersResponse>;
}
export declare function queryActivityCounters(httpClient: HttpClient): QueryActivityCountersSignature;
interface QueryActivityCountersSignature {
    /**
     * Returns up to 100 public activity counters for the provided filter and paging.
     *
     * Only counters that are marked as public are returned.
     *
     * Supported fields for filtering:
     * - `memberId`
     *
     * Supported operations:
     *
     * Comparison:
     * - $eq
     * - $ne
     * - $in
     *
     * Logical:
     * - $and
     * - $not
     * - $or
     * @param - Information about the activity counters to retrieve.
     */
    (): ActivityCountersQueryBuilder;
}
export declare const onActivityCounterUpdated: EventDefinition<ActivityCounterUpdatedEnvelope, "wix.members.v1.activity_counter_updated">;
export { ActionEvent, ActivityCounter, ActivityCounterUpdatedEnvelope, ActivityCountersQueryBuilder, ActivityCountersQueryResult, BaseEventMetadata, Counter, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GetActivityCountersRequest, GetActivityCountersResponse, IdentificationData, IdentificationDataIdOneOf, IncrementActivityCountersRequest, IncrementActivityCountersResponse, MessageEnvelope, Paging, PagingMetadata, Query, QueryActivityCountersRequest, QueryActivityCountersResponse, RestoreInfo, SetActivityCountersRequest, SetActivityCountersResponse, WebhookIdentityType, } from './members-v1-activity-counter-activity-counters.universal.js';
