import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Sets activity counters for a requested site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
export declare function setActivityCounters(payload: object): RequestOptionsFactory<any>;
/**
 * Increments a specific activity counters for a specified site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
export declare function incrementActivityCounters(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves activity counters for the specified site member, including all public counters and any private counters owned by the authenticated caller.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 */
export declare function getActivityCounters(payload: object): RequestOptionsFactory<any>;
/**
 * Returns up to 100 public activity counters for the provided filter and paging.
 *
 * Only counters that are marked as public are returned.
 *
 * Supported fields for filtering:
 * - `memberId`
 *
 * Supported operations:
 *
 * Comparison:
 * - $eq
 * - $ne
 * - $in
 *
 * Logical:
 * - $and
 * - $not
 * - $or
 */
export declare function queryActivityCounters(payload: object): RequestOptionsFactory<any>;
